
Welcome to Hist's documentation!
================================


Introduction
------------

`Hist <https://github.com/scikit-hep/hist>`_ is a powerful Histogramming tool for analysis based on `boost-histogram <https://boost-histogram.readthedocs.io/en/latest/index.html>`_ (the Python binding of the Histogram library in Boost). It is a friendly analysis-focused project that uses `boost-histogram <https://boost-histogram.readthedocs.io/en/latest/index.html>`_ as a backend to do the work, but provides plotting tools, shortcuts, and new ideas.

To get an idea of creating histograms in Hist looks like, you can take a look at the :doc:`Examples <examples/index>`. Once you have a feel for what is involved in using Hist, we recommend you start by following the instructions in :doc:`Installation </installation/index>`. Then, go through the :doc:`User Guide </user-guide/index>`, and read the :doc:`Reference </reference/modules>` documentation. We value your contributions and you can follow the instructions in :doc:`Development </development/index>`. Finally, if you’re having problems, please do let us know at our :doc:`Support </support/index>` page.


.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: Contents
   :glob:

   installation/index
   user-guide/index
   examples/index
   development/index
   support/index

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: API Reference
   :glob:

   reference/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
